"use client";

import { zodResolver } from "@hookform/resolvers/zod";
import { useForm } from "react-hook-form";
import { z } from "zod";

import { Button } from "@/components/ui/button";
import {
  Form,
  FormControl,
  FormField,
  FormItem,
  FormLabel,
  FormMessage,
} from "@/components/ui/form";
import { toast } from "@/components/ui/use-toast";
import { Input } from "./ui/input";
import {
  Select,
  SelectContent,
  SelectItem,
  SelectTrigger,
  SelectValue,
} from "./ui/select";
import { Textarea } from "./ui/textarea";
import { ApiCommunication } from "@/types/api-communication";

const displayFormSchema = z.object({
  pt: z
    .string({
      required_error: "PT is required.",
    })
    .trim()
    .min(1, "PT is required."),
  messages: z
    .string({
      required_error: "Messages are required.",
    })
    .trim()
    .min(1, "Messages is required."),
  completion: z
    .string({
      required_error: "Completion is required.",
    })
    .trim()
    .min(1, "Completion is required."),
  ct: z
    .string({
      required_error: "CT is required.",
    })
    .trim()
    .min(1, "CT is required."),
  tt: z
    .string({
      required_error: "TT is required.",
    })
    .trim()
    .min(1, "TT is required."),
  status: z
    .string({
      required_error: "Status is required.",
    })
    .trim()
    .min(1, "Status is required."),
  type: z
    .string({
      required_error: "Type is required.",
    })
    .trim()
    .min(1, "Type is required."),
  evaluation: z
    .string({
      required_error: "Evaluation is required.",
    })
    .trim()
    .min(1, "Evaluation is required."),
});

type DisplayFormValues = z.infer<typeof displayFormSchema>;

// This can come from your database or API.
const defaultValues: Partial<DisplayFormValues> = {
  pt: "",
  messages: "",
  completion: "",
  ct: "",
  tt: "",
  status: "",
  type: "",
  evaluation: "",
};

type Props = {
  apiCommunication?: ApiCommunication;
  onSubmit: () => void;
  btn1_content: string;
  btn2_content: string;
};

export default function APICommunicationForm({
  apiCommunication,
  onSubmit: onFormSubmit,
  btn1_content,
  btn2_content,
}: Props) {
  const form = useForm<DisplayFormValues>({
    resolver: zodResolver(displayFormSchema),
    defaultValues: {
      pt: apiCommunication?.pt ? String(apiCommunication.pt) : "",
      messages: apiCommunication?.messages || "",
      completion: apiCommunication?.completion || "",
      ct: apiCommunication?.ct ? String(apiCommunication.ct) : "",
      tt: apiCommunication?.tt ? String(apiCommunication.tt) : "",
      status: apiCommunication?.status || "",
      type: apiCommunication?.type || "",
      evaluation: apiCommunication?.evaluation || "",
    },
  });

  function onSubmit(data: DisplayFormValues) {
    toast({
      title: "You submitted the following values:",
      description: (
        <pre className="mt-2 w-[340px] rounded-md bg-slate-950 p-4">
          <code className="text-white">{JSON.stringify(data, null, 2)}</code>
        </pre>
      ),
    });

    onFormSubmit();
  }

  return (
    <Form {...form}>
      <form onSubmit={form.handleSubmit(onSubmit)} className="space-y-8">
        <FormField
          control={form.control}
          name="pt"
          render={({ field }) => (
            <FormItem>
              <FormLabel>PT</FormLabel>
              <FormControl>
                <Input placeholder="Enter PT..." {...field} />
              </FormControl>
              <FormMessage />
            </FormItem>
          )}
        />

        <FormField
          control={form.control}
          name="messages"
          render={({ field }) => (
            <FormItem>
              <FormLabel>Messages</FormLabel>
              <FormControl>
                <Textarea placeholder="Enter messages..." {...field} />
              </FormControl>
              <FormMessage />
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name="completion"
          render={({ field }) => (
            <FormItem>
              <FormLabel>Completion</FormLabel>
              <FormControl>
                <Textarea placeholder="Enter completion..." {...field} />
              </FormControl>
              <FormMessage />
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name="ct"
          render={({ field }) => (
            <FormItem>
              <FormLabel>CT</FormLabel>
              <FormControl>
                <Input placeholder="Enter CT..." {...field} />
              </FormControl>
              <FormMessage />
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name="tt"
          render={({ field }) => (
            <FormItem>
              <FormLabel>TT</FormLabel>
              <FormControl>
                <Input placeholder="Enter TT..." {...field} />
              </FormControl>
              <FormMessage />
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name="status"
          render={({ field }) => (
            <FormItem>
              <FormLabel>Status</FormLabel>
              <FormControl>
                <Input placeholder="Enter Status..." {...field} />
              </FormControl>
              <FormMessage />
            </FormItem>
          )}
        />
        <FormField
          control={form.control}
          name="type"
          render={({ field }) => (
            <FormItem>
              <FormLabel>Type</FormLabel>
              <FormControl>
                <Input placeholder="Enter type..." {...field} />
              </FormControl>
              <FormMessage />
            </FormItem>
          )}
        />

        <FormField
          control={form.control}
          name="evaluation"
          render={({ field }) => (
            <FormItem>
              <FormLabel>Evaluation</FormLabel>
              <Select onValueChange={field.onChange} defaultValue={field.value}>
                <FormControl>
                  <SelectTrigger>
                    <SelectValue placeholder="Select a Evaluation" />
                  </SelectTrigger>
                </FormControl>
                <SelectContent>
                  <SelectItem className="truncate" value="Uploaded at: 2023-09-20 00:00:00 - Uploader: jschultz@php.net - Developer: fabien@potencier.org - Status: finished">
                    Uploaded at: 2023-09-20 00:00:00 - Uploader:
                    jschultz@php.net - Developer: fabien@potencier.org - Status:
                    finished
                  </SelectItem>
                  
                </SelectContent>
              </Select>
              <FormMessage />
            </FormItem>
          )}
        />

        <div className="flex items-center gap-4 flex-col sm:flex-row">
          <Button className="w-full" size="lg">
            {btn1_content}
          </Button>
          <Button variant="secondary" className="w-full" size="lg">
            {btn2_content}
          </Button>
        </div>
      </form>
    </Form>
  );
}
